body,html{margin:0;padding:0;height:100%;font-family:Helvetica Neue,Helvetica,PingFang SC,Hiragino Sans GB,Microsoft YaHei,"\5FAE\8F6F\96C5\9ED1",Arial,sans-serif}.container[data-v-615a8dde]{min-height:100%;width:100%;position:relative}.el-header[data-v-615a8dde]{background-color:#b3c0d1;color:#333;text-align:center;line-height:60px;height:60px}.el-main[data-v-615a8dde]{background-color:#fff;color:#333;text-align:center;margin-bottom:80px}.el-main[data-v-615a8dde]::-webkit-scrollbar{display:none}.el-footer[data-v-615a8dde]{background-color:#f9fcff;color:#333;text-align:center;padding:10px 30px;width:100%}.el-breadcrumb[data-v-74860959]{padding:20px 0}.grid-content[data-v-272703e1]{border-radius:4px;min-height:36px;margin-top:10px}.text-left[data-v-272703e1]{text-align:left}.text-right[data-v-272703e1]{text-align:right}.m-l-0[data-v-272703e1]{margin-left:0}.m-r-20[data-v-272703e1]{margin-right:40px}.upload-demo[data-v-272703e1]{display:inline-block;margin-right:10px}#contextStyle[data-v-272703e1]{border:none}hr[data-v-272703e1]{background-color:#e5e5e5;border:none;height:1px}#contextStyle .list-button[data-v-272703e1]{display:block;width:100%;margin:0;border:none;text-align:left}