# Generated by Django 3.0.2 on 2020-01-03 08:33

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='NetDiskUser',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('platform', models.CharField(default='default', max_length=256, verbose_name='所属平台')),
                ('username', models.CharField(max_length=256, verbose_name='用户名')),
                ('systemUsername', models.CharField(max_length=256, verbose_name='系统用户名')),
                ('cluster', models.CharField(max_length=256, verbose_name='集群')),
                ('token', models.CharField(blank=True, max_length=128, null=True, verbose_name='令牌')),
                ('tokenGererateTime', models.IntegerField(blank=True, null=True, verbose_name='令牌生成时间戳')),
                ('tokenValidityPeriod', models.IntegerField(default=3600, verbose_name='令牌有效期')),
            ],
            options={
                'verbose_name': '网盘用户',
                'verbose_name_plural': '网盘用户',
                'db_table': 'netDiskUser',
                'unique_together': {('cluster', 'systemUsername')},
            },
        ),
    ]
