body,html{margin:0;padding:0;height:100%;font-family:Helvetica Neue,Helvetica,PingFang SC,Hiragino Sans GB,Microsoft YaHei,"\5FAE\8F6F\96C5\9ED1",Arial,sans-serif}.container[data-v-615a8dde]{min-height:100%;width:100%;position:relative}.el-header[data-v-615a8dde]{background-color:#b3c0d1;color:#333;text-align:center;line-height:60px;height:60px}.el-main[data-v-615a8dde]{background-color:#fff;color:#333;text-align:center;margin-bottom:80px}.el-main[data-v-615a8dde]::-webkit-scrollbar{display:none}.el-footer[data-v-615a8dde]{background-color:#f9fcff;color:#333;text-align:center;padding:10px 30px;width:100%}.bordernone[data-v-8fefe130] .el-input__inner{border:0 solid #b6d8f1}.el-form-item[data-v-8fefe130]{margin-bottom:10px}.el-form--inline[data-v-8fefe130]{text-align:right;margin-right:10px}.uploader-example[data-v-59cc7442]{width:880px;padding:15px;margin:0 auto 0;font-size:14px;-webkit-box-shadow:0 0 10px rgba(0,0,0,.4);box-shadow:0 0 10px rgba(0,0,0,.4)}.uploader-example .uploader-btn[data-v-59cc7442]{margin-right:4px}.uploader-example .uploader-list[data-v-59cc7442]{max-height:440px;overflow:auto;overflow-x:hidden;overflow-y:auto}.grid-content[data-v-59cc7442]{border-radius:4px;min-height:36px;margin-top:10px}.text-left[data-v-59cc7442]{text-align:left}.text-right[data-v-59cc7442]{text-align:right}.m-l-0[data-v-59cc7442]{margin-left:0}.m-r-20[data-v-59cc7442]{margin-right:40px}.upload-demo[data-v-59cc7442]{display:inline-block;margin-right:10px}.footer[data-v-59cc7442]{position:fixed;bottom:0;background-color:#f9fcff;color:#333;text-align:center;width:100%;padding:20px 0;z-index:999}.has-gutter[data-v-59cc7442]{border-top:2px solid #e5e5e5!important}.bordernone[data-v-59cc7442] .el-input__inner{border:0 solid #b6d8f1}.el-form--inline[data-v-59cc7442] .el-form-item__label.el-form-item__label{color:#e5e5e5}#contextStyle[data-v-59cc7442]{border:none}#contextStyle .list-button[data-v-59cc7442]{display:block;width:100%;margin:0;border:none;text-align:left}hr[data-v-59cc7442]{background-color:#e5e5e5;border:none;height:1px}.el-dialog .el-dialog__body[data-v-59cc7442]{padding-top:0!important}.linehight th[data-v-59cc7442]{padding:10px 0!important}.linehight td[data-v-59cc7442]{padding:6px 0!important}.border[data-v-59cc7442]{padding:10px;border:1px solid #e5e5e5}.clicked[data-v-59cc7442]{background:#34b4e3}.circle[data-v-59cc7442]{position:relative}.circle-ul[data-v-59cc7442]{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:start;-ms-flex-pack:start;justify-content:flex-start;-ms-flex-wrap:wrap;flex-wrap:wrap;padding:0}.circle-li[data-v-59cc7442]{width:100px;margin-right:40px;list-style:none;margin-bottom:10px;height:140px}.circle-li .el-checkbox .el-checkbox__input[data-v-59cc7442]{vertical-align:middle}.uploader-example[data-v-087d42bb][data-v-59cc7442]{-webkit-box-shadow:rgba(0,0,0,.1) 0 0 10px;box-shadow:0 0 10px rgba(0,0,0,.1);-webkit-box-shadow:0 0 10px rgba(0,0,0,.05);box-shadow:0 0 10px rgba(0,0,0,.05)}.uploader-btn[data-v-59cc7442]{color:#409eff;border:1px solid #409eff}.uploader-btn[data-v-59cc7442]:hover{background-color:#409eff;color:#fff}.add-dialog[data-v-59cc7442] .el-dialog__body{padding:20px 20px!important}.uploader-example[data-v-59cc7442]{width:auto}.el-main{background:#fff}.el-drawer__header{margin-bottom:10px}