# Generated by Django 3.0.2 on 2020-01-03 09:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('thStorage', '0002_auto_20200103_1718'),
    ]

    operations = [
        migrations.CreateModel(
            name='NetDiskTrashbin',
            fields=[
                ('id', models.AutoField(max_length=12, primary_key=True, serialize=False)),
                ('cluster', models.CharField(max_length=256, verbose_name='所属集群')),
                ('username', models.CharField(max_length=256, verbose_name='用户名')),
                ('sourcePath', models.CharField(max_length=512, verbose_name='源路径')),
                ('sourceFilename', models.CharField(max_length=256, verbose_name='源文件名称')),
                ('trashFilename', models.CharField(max_length=64, verbose_name='回收站文件名')),
                ('deleteTime', models.DateTimeField(auto_now_add=True, verbose_name='删除时间')),
            ],
            options={
                'verbose_name': '回收站',
                'verbose_name_plural': '回收站',
                'db_table': 'netDiskTrashbin',
            },
        ),
        migrations.RenameField(
            model_name='netdiskuser',
            old_name='token',
            new_name='tokenDesk',
        ),
        migrations.RenameField(
            model_name='netdiskuser',
            old_name='tokenGererateTime',
            new_name='tokenGererateTimeDesk',
        ),
        migrations.AddField(
            model_name='netdiskuser',
            name='tokenGererateTimeWeb',
            field=models.IntegerField(blank=True, null=True, verbose_name='令牌生成时间戳'),
        ),
        migrations.AddField(
            model_name='netdiskuser',
            name='tokenWeb',
            field=models.CharField(blank=True, max_length=128, null=True, verbose_name='令牌'),
        ),
    ]
