<!DOCTYPE html><html lang=zh-cn><head><meta charset=utf-8><meta http-equiv=X-UA-Compatible content="IE=edge"><meta name=viewport content="width=device-width,initial-scale=1"><link rel=icon href=/static/img/favicon.ico><title>home</title><link href=/static/css/chunk-vendors.0340a989.css rel=preload as=style><link href=/static/css/home.1ff26df9.css rel=preload as=style><link href=/static/js/chunk-vendors.e86679ac.js rel=preload as=script><link href=/static/js/home.a5e511c7.js rel=preload as=script><link href=/static/css/chunk-vendors.0340a989.css rel=stylesheet><link href=/static/css/home.1ff26df9.css rel=stylesheet></head><body><noscript><strong>We're sorry but vue_demo doesn't work properly without JavaScript enabled. Please enable it to continue.</strong></noscript><div id=app></div><script src=/static/js/chunk-vendors.e86679ac.js></script><script src=/static/js/home.a5e511c7.js></script></body></html>