# Generated by Django 3.0.2 on 2020-01-03 09:18

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('thStorage', '0001_initial'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='netdiskuser',
            unique_together={('cluster', 'username')},
        ),
    ]
