# Generated by Django 3.0.2 on 2020-01-03 09:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('thStorage', '0003_auto_20200103_1729'),
    ]

    operations = [
        migrations.AlterField(
            model_name='netdiskuser',
            name='tokenGererateTimeDesk',
            field=models.IntegerField(blank=True, null=True, verbose_name='桌面令牌生成时间戳'),
        ),
        migrations.AlterField(
            model_name='netdiskuser',
            name='tokenGererateTimeWeb',
            field=models.IntegerField(blank=True, null=True, verbose_name='web令牌生成时间戳'),
        ),
    ]
